ImageStore
==========

An image gallery, created for easy integration for an exiting django project.

`Documentation aviable on ReadTheDocs <http://readthedocs.org/projects/imagestore/>`_

Gallery for site
----------------

* Albums
* Mass upload
* Thumbnails in admin intereface
* Ordering
* Tagging support
* Easy PrettyPhoto integration
* Django-cms integration

Gallery for your site users
---------------------------

* You can use imagestore to create gallery for your users.
* Users can:
    * create albums, upload photos to albums
    * make albums non-public
    * set name, descripion and tags for photos
    * edit infomation about photo or upload new veresion

